import { fetchAnnouncementById } from "@/lib/api";
import { Announcement } from "@/lib/types";
import { formatDateToMonthDayYear } from "@/lib/utils";

export const metadata = {
    title: 'Announcement Detail Page',
    description: 'NullTranslationGroup Announcement page',
};

export type paramsType = Promise<{ announcementId: string }>;

export default async function AnnouncementDetailPage(props: {params: paramsType}) {
    const { announcementId } = await props.params;
    let announcement: Announcement;
    try{
        announcement = await fetchAnnouncementById(announcementId);
    }
    catch (error) {
        console.error(error);
        return (    
            <div className="prose dark:prose-invert mx-auto p-6 bg-white dark:bg-gray-800 shadow-md rounded-lg mt-4">
                <div dangerouslySetInnerHTML={{ __html: '<center><h1> Announcement not found !</h1></center>' }}></div>
            </div>
        )
    }
    return (
        <div className="prose dark:prose-invert mx-auto p-6 bg-white dark:bg-gray-800 shadow-md rounded-lg mt-4">
            <h1>{announcement.title}</h1>
            <h2>Release Date: {formatDateToMonthDayYear(new Date(announcement.datetime))}</h2>
            <div dangerouslySetInnerHTML={{ __html: announcement.content }}></div>
        </div>
    )
}
