import { formatDateToMonthDayYear } from "@/lib/utils";
import { Announcement } from "@/lib/types";
import { fetchAnnouncements } from "@/lib/api";
import Link from "next/link";


export const metadata = {
    title: 'Annoucement page',
    description: 'NullTranslationGroup Announcement page',
};

export default async function AnnouncementPage() {
    let announcements = [];
    try {
        announcements = await fetchAnnouncements();
    } catch (error) {
        console.error(error);
        return (
            <div className="text-center mt-10 text-red-500">
                <p>Failed to load announcements.</p>
            </div>
        );
    }

    const sorted_announcements:Announcement[] = announcements.sort((a, b) => new Date(a.datetime).getTime() -  new Date(b.datetime).getTime());


    return (
            <div className="max-w-6xl mx-auto py-10 px-4">                    
                {sorted_announcements.map((announcement) => (
                    <Link href = {`/announcements/${announcement.documentId}`} key={announcement.documentId}>
                        <li key={announcement.id} className="mb-2 list-none">
                            <div className="text-lg font-semibold">{announcement.title}</div>
                            <div className="text-sm text-gray-500">{formatDateToMonthDayYear(new Date(announcement.datetime))}</div>
                        </li>
                    </Link>
                ))}
            </div>
        );
            
}
